==> vis_package-1.0.2-py3-none-any.whl: vis_package/vis_method.py <==
import pandas as pd
import math
import numpy as np
import heapq
from scipy.stats.mstats import gmean, hmean 

from vis_package.power_method import Power
from vis_package.complete_method import Complete

class VIS(Power, Complete):
    def __init__(self) -> None:
        Power.__init__(self)
        Complete.__init__(self)

    def create_exp_option(self, time_moment, number_fomula = 5000, profit_condition = 1.4, method = 'complete', module = 'basic'):
        '''
        time_moment:        số năm muốn test
        number_ct:          số công thức muốn lấy
        profit_condition:   lợi nhuận tối thiểu công thức muốn lấy
        '''
        if module == 'basic':
            self.get_profit = self.get_profit_basic
            self.data_full = self.data_full.sort_values(by=['TIME', 'SYMBOL'], ascending=[False, True], ignore_index=True)
        else:
            self.data_full = self.data_full.sort_values(by=['TIME', 'PROFIT'], ascending=[False, False], ignore_index=True)
            if module == 'rank':
                self.get_profit = self.get_profit_harmean_rank
            else:
                self.get_profit = self.get_profit_RankCorrelation
        self._time_moment = time_moment
        self._number_ct = number_fomula
        self._profit_condition = profit_condition
        self._index_T = self._get_index_T()
        self.data_test = self.data_full.loc()[self._index_T[-self._time_moment]:self._index_T[-1]].reset_index(drop=True)
        self._index_test = self._get_index_T(for_data= 'test')
        self._len_data_i = []
        for i in range(1, len(self._index_test)):
            self._len_data_i.append(self._index_test[i]-self._index_test[i-1])
        self.get_variable()
        # print('DONE đọc biến', self._alpha, self._alpha_power)
        self._run(method)
        if method == 'complete':
            print('lưu complete')
            self._save_process_complete()
        elif method == 'power':
            print('lưu power')
            self._save_process_power()

        file_fomula = pd.DataFrame({'fomula': self._exp_high_profit, 'profit': self._high_profit})

        return file_fomula

    def _run(self, method):
        if method == 'complete':
            self._update_last_time_complete()
            print('chạy complete')
            self._alpha_complete = self._alpha
            while True:
                try:
                    self._index_file_complete = self._index_file_qk_complete
                    self._creat_Exp_complete()
                except:
                    break
        elif method == 'power':
            self._update_last_time_power()
            print('chạy power')
            self._alpha_power = self._alpha.replace('A', '')
            # print('DONE đọc biến power', self._alpha, self._alpha_power)

            while True:
                try:
                    self._index_file_power = self._index_file_qk_power
                    self._create_Exp_power()
                except:
                    break

==> vis_package-1.0.3-py3-none-any.whl: vis_package/vis_method.py <==
import pandas as pd
import math
import numpy as np
import heapq
from scipy.stats.mstats import gmean, hmean 

from vis_package.power_method import Power
from vis_package.complete_method import Complete

class VIS(Power, Complete):
    def __init__(self) -> None:
        Power.__init__(self)
        Complete.__init__(self)

    def create_exp_option(self, time_moment, number_fomula = 5000, profit_condition = 1.4, method = 'complete', module = 'basic'):
        '''
        time_moment:        số năm muốn test
        number_ct:          số công thức muốn lấy
        profit_condition:   lợi nhuận tối thiểu công thức muốn lấy
        '''
        if module == 'basic':
            self.get_profit = self.get_profit_basic
            self.data_full = self.data_full.sort_values(by=['TIME', 'PROFIT'], ascending=[False, True], ignore_index=True)
        else:
            self.data_full = self.data_full.sort_values(by=['TIME', 'PROFIT'], ascending=[False, False], ignore_index=True)
            if module == 'rank':
                self.get_profit = self.get_profit_harmean_rank
            else:
                self.get_profit = self.get_profit_RankCorrelation
        self._time_moment = time_moment
        self._number_ct = number_fomula
        self._profit_condition = profit_condition
        self._index_T = self._get_index_T()
        self.data_test = self.data_full.loc()[self._index_T[-self._time_moment]:self._index_T[-1]].reset_index(drop=True)
        self._index_test = self._get_index_T(for_data= 'test')
        self._len_data_i = []
        for i in range(1, len(self._index_test)):
            self._len_data_i.append(self._index_test[i]-self._index_test[i-1])
        self.get_variable()
        # print('DONE đọc biến', self._alpha, self._alpha_power)
        self._run(method)
        
        if method == 'complete':
            print('lưu complete')
            self._save_process_complete()
        elif method == 'power':
            print('lưu power')
            self._save_process_power()

        file_fomula = pd.DataFrame({'fomula': self._exp_high_profit, 'profit': self._high_profit})

        return file_fomula

    def _run(self, method):
        if method == 'complete':
            self._update_last_time_complete()
            print('chạy complete')
            self._alpha_complete = self._alpha
            while True:
                try:
                    self._index_file_complete = self._index_file_qk_complete
                    self._creat_Exp_complete()
                except:
                    break
        elif method == 'power':
            self._update_last_time_power()
            print('chạy power')
            self._alpha_power = self._alpha.replace('A', '')

            while True:
                try:
                    self._index_file_power = self._index_file_qk_power
                    self._create_Exp_power()
                except:
                    break
